@@ -271,14 +271,16 @@ visr.survfit <- function(x = NULL,
   )) +
     ggplot2::geom_step(ggplot2::aes(y = est, col = strata)) +
     ggplot2::scale_x_continuous(
-      breaks = x_ticks,
-      limits = c(min(x_ticks), max(x_ticks))
+      breaks = x_ticks
     ) +
     ggplot2::xlab(x_label) +
     ggplot2::scale_y_continuous(
       breaks = y_ticks,
-      labels = yscaleFUN,
-      limits = c(min(y_ticks), max(y_ticks))
+      labels = yscaleFUN
+    ) +
+    ggplot2::coord_cartesian(
+      xlim = c(min(x_ticks), max(x_ticks)),
+      ylim = c(min(y_ticks), max(y_ticks))
     ) +
     ggplot2::ylab(y_label) +
     ggplot2::labs(color = .construct_strata_label(x)) +
@@ -533,14 +535,16 @@ visr.tidycuminc <- function(x = NULL,
     )) +
     ggplot2::geom_step(ggplot2::aes(y = est, col = strata)) +
     ggplot2::scale_x_continuous(
-      breaks = x_ticks,
-      limits = c(min(x_ticks), max(x_ticks))
+      breaks = x_ticks
     ) +
     ggplot2::xlab(x_label) +
     ggplot2::scale_y_continuous(
       breaks = y_ticks,
-      labels = yscaleFUN,
-      limits = c(min(y_ticks), max(y_ticks))
+      labels = yscaleFUN
+    ) +
+    ggplot2::coord_cartesian(
+      xlim = c(min(x_ticks), max(x_ticks)),
+      ylim = c(min(y_ticks), max(y_ticks))
     ) +
     ggplot2::ylab(y_label) +
     ggplot2::labs(color = .construct_strata_label(x)) +
